# Olesik et al 2022
Following examples are used in article named "On numerical broadening of particle size spectra:\\
a condensational growth study using PyMPDATA" (https://arxiv.org/abs/2011.14726)
 
## Examples/Demos:
- plots (Figures 1-9):
  [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/atmos-cloud-sim-uj/PyMPDATA-examples.git/master?filepath=PyMPDATA_examples%2FOlesik_et_al_2022/demo_make_plots.ipynb)
  [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/atmos-cloud-sim-uj/PyMPDATA-examples/blob/master/PyMPDATA_examples/Olesik_et_al_2022/demo_make_plots.ipynb) 
  
- relative diaspersion (Table 1):
  [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/atmos-cloud-sim-uj/PyMPDATA-examples.git/master?filepath=PyMPDATA_examples%2FOlesik_et_al_2022/demo_make_dispersion_ratio.ipynb)
  [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/atmos-cloud-sim-uj/PyMPDATA-examples/blob/master/PyMPDATA_examples/Olesik_et_al_2022/demo_make_dispersion_ratio.ipynb)   
 
- wall times (Table 2):
  [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/atmos-cloud-sim-uj/PyMPDATA-examples.git/master?filepath=PyMPDATA_examples%2FOlesik_et_al_2022/demo_wall_times.ipynb)
  [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/atmos-cloud-sim-uj/PyMPDATA-examples/blob/master/PyMPDATA_examples/Olesik_et_al_2022/demo_wall_times.ipynb) 
  
- appendix (Figures A1-A9):
  [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/atmos-cloud-sim-uj/PyMPDATA-examples.git/master?filepath=PyMPDATA_examples%2FOlesik_et_al_2022/demo_make_convergences.ipynb)
  [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/atmos-cloud-sim-uj/PyMPDATA-examples/blob/master/PyMPDATA_examples/Olesik_et_al_2022/demo_make_convergences.ipynb) 
